@@ -29,6 +29,7 @@ from oslo_utils import strutils
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
 from redis import exceptions as redis_exceptions
+from redis import sentinel
 import six
 from six.moves import range as compat_range
 
@@ -156,6 +157,9 @@ class RedisJob(base.Job):
         return ((self.board.listings_key, self.priority, self.sequence) ==
                 (other.board.listings_key, other.priority, other.sequence))
 
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     def __hash__(self):
         return hash((self.board.listings_key, self.priority, self.sequence))
 
@@ -250,9 +254,9 @@ class RedisJobBoard(base.JobBoard):
     claim is kept alive while it is being worked on by using
     the :py:meth:`~.RedisJob.extend_expiry` method periodically.
 
-    .. _msgpack: http://msgpack.org/
-    .. _redis: http://redis.io/
-    .. _hash: http://redis.io/topics/data-types#hashes
+    .. _msgpack: https://msgpack.org/
+    .. _redis: https://redis.io/
+    .. _hash: https://redis.io/topics/data-types#hashes
     """
 
     CLIENT_CONF_TRANSFERS = tuple([
@@ -407,12 +411,10 @@ if redis.call("hexists", listings_key, job_key) == 1 then
             -- Owner is the same, leave it alone...
             redis.call("set", last_modified_key, last_modified_blob)
             apply_ttl(owner_key, ms_expiry)
-            result["status"] = "${ok}"
-        else
-            result["status"] = "${error}"
-            result["reason"] = "${already_claimed}"
-            result["owner"] = owner
         end
+        result["status"] = "${error}"
+        result["reason"] = "${already_claimed}"
+        result["owner"] = owner
     else
         redis.call("set", owner_key, expected_owner)
         redis.call("set", last_modified_key, last_modified_blob)
@@ -566,7 +568,19 @@ return cmsgpack.pack(result)
                     client_conf[key] = value_type_converter(conf[key])
                 else:
                     client_conf[key] = conf[key]
-        return ru.RedisClient(**client_conf)
+        if conf.get('sentinel') is not None:
+            sentinel_conf = {}
+            # sentinel do not have ssl kwargs
+            for key in client_conf:
+                if 'ssl' not in key:
+                    sentinel_conf[key] = client_conf[key]
+            s = sentinel.Sentinel([(sentinel_conf.pop('host'),
+                                    sentinel_conf.pop('port'))],
+                                  sentinel_kwargs=conf.get('sentinel_kwargs'),
+                                  **sentinel_conf)
+            return s.master_for(conf['sentinel'])
+        else:
+            return ru.RedisClient(**client_conf)
 
     def __init__(self, name, conf,
                  client=None, persistence=None):
@@ -814,9 +828,9 @@ return cmsgpack.pack(result)
                 job_details = job_data.get('details', {})
             except (ValueError, TypeError, KeyError):
                 with excutils.save_and_reraise_exception():
-                    LOG.warn("Incorrectly formatted job data found at"
-                             " key: %s[%s]", self.listings_key,
-                             raw_job_key, exc_info=True)
+                    LOG.warning("Incorrectly formatted job data found at"
+                                " key: %s[%s]", self.listings_key,
+                                raw_job_key, exc_info=True)
             else:
                 postings.append(RedisJob(self, job_name, job_sequence_id,
                                          raw_job_key, uuid=job_uuid,
