@@ -15,8 +15,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import absolute_import
-
 import contextlib
 import copy
 import functools
@@ -24,12 +22,12 @@ import threading
 import time
 
 from oslo_utils import strutils
-import retrying
 import six
 import sqlalchemy as sa
 from sqlalchemy import exc as sa_exc
 from sqlalchemy import pool as sa_pool
 from sqlalchemy import sql
+import tenacity
 
 from taskflow import exceptions as exc
 from taskflow import logging
@@ -176,10 +174,10 @@ def _ping_listener(dbapi_conn, connection_rec, connection_proxy):
         dbapi_conn.cursor().execute('select 1')
     except dbapi_conn.OperationalError as ex:
         if _in_any(six.text_type(ex.args[0]), MY_SQL_GONE_WAY_AWAY_ERRORS):
-            LOG.warn('Got mysql server has gone away', exc_info=True)
+            LOG.warning('Got mysql server has gone away', exc_info=True)
             raise sa_exc.DisconnectionError("Database server went away")
         elif _in_any(six.text_type(ex.args[0]), POSTGRES_GONE_WAY_AWAY_ERRORS):
-            LOG.warn('Got postgres server has gone away', exc_info=True)
+            LOG.warning('Got postgres server has gone away', exc_info=True)
             raise sa_exc.DisconnectionError("Database server went away")
         else:
             raise
@@ -362,7 +360,7 @@ class Connection(base.Connection):
         """Performs basic **connection** validation of a sqlalchemy engine."""
 
         def _retry_on_exception(exc):
-            LOG.warn("Engine connection (validate) failed due to '%s'", exc)
+            LOG.warning("Engine connection (validate) failed due to '%s'", exc)
             if isinstance(exc, sa_exc.OperationalError) and \
                _is_db_connection_error(six.text_type(exc.args[0])):
                 # We may be able to fix this by retrying...
@@ -375,14 +373,12 @@ class Connection(base.Connection):
             # Other failures we likely can't fix by retrying...
             return False
 
-        @retrying.retry(stop_max_attempt_number=max(0, int(max_retries)),
-                        # Ensure that the 2 ** retry number
-                        # is converted into milliseconds (thus why this
-                        # multiplies by 1000.0) because thats what retrying
-                        # lib. uses internally for whatever reason.
-                        wait_exponential_multiplier=1000.0,
-                        wrap_exception=False,
-                        retry_on_exception=_retry_on_exception)
+        @tenacity.retry(
+            stop=tenacity.stop_after_attempt(max(0, int(max_retries))),
+            wait=tenacity.wait_exponential(),
+            reraise=True,
+            retry=tenacity.retry_if_exception(_retry_on_exception)
+        )
         def _try_connect(engine):
             # See if we can make a connection happen.
             #
