@@ -14,15 +14,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import absolute_import
-
 import collections
 import logging
 
 import fixtures
 import mock
 from oslotest import base
-from oslotest import mockpatch
 import six
 
 from testtools import compat
@@ -123,8 +120,8 @@ class TestCase(base.BaseTestCase):
 
         self.assertRaises(exc_class, access_func)
 
-    def assertRaisesRegexp(self, exc_class, pattern, callable_obj,
-                           *args, **kwargs):
+    def assertRaisesRegex(self, exc_class, pattern, callable_obj,
+                          *args, **kwargs):
         # TODO(harlowja): submit a pull/review request to testtools to add
         # this method to there codebase instead of having it exist in ours
         # since it really doesn't belong here.
@@ -185,7 +182,7 @@ class TestCase(base.BaseTestCase):
         except exceptions.WrappedFailure as e:
             self.assertThat(e, FailureRegexpMatcher(exc_class, pattern))
 
-    def assertItemsEqual(self, seq1, seq2, msg=None):
+    def assertCountEqual(self, seq1, seq2, msg=None):
         matcher = ItemsEqual(seq1)
         self.assertThat(seq2, matcher)
 
@@ -198,8 +195,8 @@ class MockTestCase(TestCase):
 
     def patch(self, target, autospec=True, **kwargs):
         """Patch target and attach it to the master mock."""
-        f = self.useFixture(mockpatch.Patch(target,
-                                            autospec=autospec, **kwargs))
+        f = self.useFixture(fixtures.MockPatch(target,
+                                               autospec=autospec, **kwargs))
         mocked = f.mock
         attach_as = kwargs.pop('attach_as', None)
         if attach_as is not None:
@@ -218,8 +215,8 @@ class MockTestCase(TestCase):
         else:
             instance_mock = mock.Mock()
 
-        f = self.useFixture(mockpatch.PatchObject(module, name,
-                                                  autospec=autospec))
+        f = self.useFixture(fixtures.MockPatchObject(module, name,
+                                                     autospec=autospec))
         class_mock = f.mock
         class_mock.return_value = instance_mock
 
