@@ -109,8 +109,8 @@ class TaskTest(test.TestCase):
         self.assertEqual({'food': 0}, my_task.save_as)
 
     def test_bad_provides(self):
-        self.assertRaisesRegexp(TypeError, '^Atom provides',
-                                MyTask, provides=object())
+        self.assertRaisesRegex(TypeError, '^Atom provides',
+                               MyTask, provides=object())
 
     def test_requires_by_default(self):
         my_task = MyTask()
@@ -144,9 +144,9 @@ class TaskTest(test.TestCase):
         self.assertEqual(expected, my_task.rebind)
 
     def test_requires_explicit_not_enough(self):
-        self.assertRaisesRegexp(ValueError, '^Missing arguments',
-                                MyTask,
-                                auto_extract=False, requires=('spam', 'eggs'))
+        self.assertRaisesRegex(ValueError, '^Missing arguments',
+                               MyTask,
+                               auto_extract=False, requires=('spam', 'eggs'))
 
     def test_requires_ignores_optional(self):
         my_task = DefaultArgTask()
@@ -189,8 +189,8 @@ class TaskTest(test.TestCase):
                          my_task.requires)
 
     def test_rebind_unknown(self):
-        self.assertRaisesRegexp(ValueError, '^Extra arguments',
-                                MyTask, rebind={'foo': 'bar'})
+        self.assertRaisesRegex(ValueError, '^Extra arguments',
+                               MyTask, rebind={'foo': 'bar'})
 
     def test_rebind_unknown_kwargs(self):
         my_task = KwargsTask(rebind={'foo': 'bar'})
@@ -223,8 +223,8 @@ class TaskTest(test.TestCase):
                          my_task.requires)
 
     def test_rebind_list_more(self):
-        self.assertRaisesRegexp(ValueError, '^Extra arguments',
-                                MyTask, rebind=('a', 'b', 'c', 'd'))
+        self.assertRaisesRegex(ValueError, '^Extra arguments',
+                               MyTask, rebind=('a', 'b', 'c', 'd'))
 
     def test_rebind_list_more_kwargs(self):
         my_task = KwargsTask(rebind=('a', 'b', 'c'))
@@ -238,8 +238,8 @@ class TaskTest(test.TestCase):
                          my_task.requires)
 
     def test_rebind_list_bad_value(self):
-        self.assertRaisesRegexp(TypeError, '^Invalid rebind value',
-                                MyTask, rebind=object())
+        self.assertRaisesRegex(TypeError, '^Invalid rebind value',
+                               MyTask, rebind=object())
 
     def test_default_provides(self):
         my_task = DefaultProvidesTask()
@@ -263,8 +263,8 @@ class TaskTest(test.TestCase):
         a_task.execute(values)
         self.assertEqual(values, result)
 
-    @mock.patch.object(task.LOG, 'warn')
-    def test_update_progress_lower_bound(self, mocked_warn):
+    @mock.patch.object(task.LOG, 'warning')
+    def test_update_progress_lower_bound(self, mocked_warning):
         result = []
 
         def progress_callback(event_type, details):
@@ -274,10 +274,10 @@ class TaskTest(test.TestCase):
         a_task.notifier.register(task.EVENT_UPDATE_PROGRESS, progress_callback)
         a_task.execute([-1.0, -0.5, 0.0])
         self.assertEqual([0.0, 0.0, 0.0], result)
-        self.assertEqual(2, mocked_warn.call_count)
+        self.assertEqual(2, mocked_warning.call_count)
 
-    @mock.patch.object(task.LOG, 'warn')
-    def test_update_progress_upper_bound(self, mocked_warn):
+    @mock.patch.object(task.LOG, 'warning')
+    def test_update_progress_upper_bound(self, mocked_warning):
         result = []
 
         def progress_callback(event_type, details):
@@ -287,10 +287,10 @@ class TaskTest(test.TestCase):
         a_task.notifier.register(task.EVENT_UPDATE_PROGRESS, progress_callback)
         a_task.execute([1.0, 1.5, 2.0])
         self.assertEqual([1.0, 1.0, 1.0], result)
-        self.assertEqual(2, mocked_warn.call_count)
+        self.assertEqual(2, mocked_warning.call_count)
 
-    @mock.patch.object(notifier.LOG, 'warn')
-    def test_update_progress_handler_failure(self, mocked_warn):
+    @mock.patch.object(notifier.LOG, 'warning')
+    def test_update_progress_handler_failure(self, mocked_warning):
 
         def progress_callback(*args, **kwargs):
             raise Exception('Woot!')
@@ -298,7 +298,7 @@ class TaskTest(test.TestCase):
         a_task = ProgressTask()
         a_task.notifier.register(task.EVENT_UPDATE_PROGRESS, progress_callback)
         a_task.execute([0.5])
-        self.assertEqual(1, mocked_warn.call_count)
+        self.assertEqual(1, mocked_warning.call_count)
 
     def test_register_handler_is_none(self):
         a_task = MyTask()
