@@ -18,6 +18,7 @@ import collections
 import os
 
 import networkx as nx
+from networkx.drawing import nx_pydot
 import six
 
 
@@ -28,13 +29,13 @@ def _common_format(g, edge_notation):
     lines.append("Frozen: %s" % nx.is_frozen(g))
     lines.append("Density: %0.3f" % nx.density(g))
     lines.append("Nodes: %s" % g.number_of_nodes())
-    for n, n_data in g.nodes_iter(data=True):
+    for n, n_data in g.nodes(data=True):
         if n_data:
             lines.append("  - %s (%s)" % (n, n_data))
         else:
             lines.append("  - %s" % n)
     lines.append("Edges: %s" % g.number_of_edges())
-    for (u, v, e_data) in g.edges_iter(data=True):
+    for (u, v, e_data) in g.edges(data=True):
         if e_data:
             lines.append("  %s %s %s (%s)" % (u, edge_notation, v, e_data))
         else:
@@ -45,8 +46,9 @@ def _common_format(g, edge_notation):
 class Graph(nx.Graph):
     """A graph subclass with useful utility functions."""
 
-    def __init__(self, data=None, name=''):
-        super(Graph, self).__init__(name=name, data=data)
+    def __init__(self, incoming_graph_data=None, name=''):
+        super(Graph, self).__init__(incoming_graph_data=incoming_graph_data,
+                                    name=name)
         self.frozen = False
 
     def freeze(self):
@@ -57,18 +59,40 @@ class Graph(nx.Graph):
 
     def export_to_dot(self):
         """Exports the graph to a dot format (requires pydot library)."""
-        return nx.to_pydot(self).to_string()
+        return nx_pydot.to_pydot(self).to_string()
 
     def pformat(self):
         """Pretty formats your graph into a string."""
         return os.linesep.join(_common_format(self, "<->"))
 
+    def add_edge(self, u, v, attr_dict=None, **attr):
+        """Add an edge between u and v."""
+        if attr_dict is not None:
+            return super(Graph, self).add_edge(u, v, **attr_dict)
+        return super(Graph, self).add_edge(u, v, **attr)
+
+    def add_node(self, n, attr_dict=None, **attr):
+        """Add a single node n and update node attributes."""
+        if attr_dict is not None:
+            return super(Graph, self).add_node(n, **attr_dict)
+        return super(Graph, self).add_node(n, **attr)
+
+    def fresh_copy(self):
+        """Return a fresh copy graph with the same data structure.
+
+        A fresh copy has no nodes, edges or graph attributes. It is
+        the same data structure as the current graph. This method is
+        typically used to create an empty version of the graph.
+        """
+        return Graph()
+
 
 class DiGraph(nx.DiGraph):
     """A directed graph subclass with useful utility functions."""
 
-    def __init__(self, data=None, name=''):
-        super(DiGraph, self).__init__(name=name, data=data)
+    def __init__(self, incoming_graph_data=None, name=''):
+        super(DiGraph, self).__init__(incoming_graph_data=incoming_graph_data,
+                                      name=name)
         self.frozen = False
 
     def freeze(self):
@@ -114,7 +138,7 @@ class DiGraph(nx.DiGraph):
 
     def export_to_dot(self):
         """Exports the graph to a dot format (requires pydot library)."""
-        return nx.to_pydot(self).to_string()
+        return nx_pydot.to_pydot(self).to_string()
 
     def is_directed_acyclic(self):
         """Returns if this graph is a DAG or not."""
@@ -122,14 +146,14 @@ class DiGraph(nx.DiGraph):
 
     def no_successors_iter(self):
         """Returns an iterator for all nodes with no successors."""
-        for n in self.nodes_iter():
-            if not len(self.successors(n)):
+        for n in self.nodes:
+            if not len(list(self.successors(n))):
                 yield n
 
     def no_predecessors_iter(self):
         """Returns an iterator for all nodes with no predecessors."""
-        for n in self.nodes_iter():
-            if not len(self.predecessors(n)):
+        for n in self.nodes:
+            if not len(list(self.predecessors(n))):
                 yield n
 
     def bfs_predecessors_iter(self, n):
@@ -142,28 +166,81 @@ class DiGraph(nx.DiGraph):
         over more than once (this prevents infinite iteration).
         """
         visited = set([n])
-        queue = collections.deque(self.predecessors_iter(n))
+        queue = collections.deque(self.predecessors(n))
         while queue:
             pred = queue.popleft()
             if pred not in visited:
                 yield pred
                 visited.add(pred)
-                for pred_pred in self.predecessors_iter(pred):
+                for pred_pred in self.predecessors(pred):
                     if pred_pred not in visited:
                         queue.append(pred_pred)
 
+    def add_edge(self, u, v, attr_dict=None, **attr):
+        """Add an edge between u and v."""
+        if attr_dict is not None:
+            return super(DiGraph, self).add_edge(u, v, **attr_dict)
+        return super(DiGraph, self).add_edge(u, v, **attr)
+
+    def add_node(self, n, attr_dict=None, **attr):
+        """Add a single node n and update node attributes."""
+        if attr_dict is not None:
+            return super(DiGraph, self).add_node(n, **attr_dict)
+        return super(DiGraph, self).add_node(n, **attr)
+
+    def fresh_copy(self):
+        """Return a fresh copy graph with the same data structure.
+
+        A fresh copy has no nodes, edges or graph attributes. It is
+        the same data structure as the current graph. This method is
+        typically used to create an empty version of the graph.
+        """
+        return DiGraph()
+
 
 class OrderedDiGraph(DiGraph):
     """A directed graph subclass with useful utility functions.
 
-    This derivative retains node, edge, insertation and iteration
-    ordering (so that the iteration order matches the insertation
+    This derivative retains node, edge, insertion and iteration
+    ordering (so that the iteration order matches the insertion
     order).
     """
     node_dict_factory = collections.OrderedDict
-    adjlist_dict_factory = collections.OrderedDict
+    adjlist_outer_dict_factory = collections.OrderedDict
+    adjlist_inner_dict_factory = collections.OrderedDict
     edge_attr_dict_factory = collections.OrderedDict
 
+    def fresh_copy(self):
+        """Return a fresh copy graph with the same data structure.
+
+        A fresh copy has no nodes, edges or graph attributes. It is
+        the same data structure as the current graph. This method is
+        typically used to create an empty version of the graph.
+        """
+        return OrderedDiGraph()
+
+
+class OrderedGraph(Graph):
+    """A graph subclass with useful utility functions.
+
+    This derivative retains node, edge, insertion and iteration
+    ordering (so that the iteration order matches the insertion
+    order).
+    """
+    node_dict_factory = collections.OrderedDict
+    adjlist_outer_dict_factory = collections.OrderedDict
+    adjlist_inner_dict_factory = collections.OrderedDict
+    edge_attr_dict_factory = collections.OrderedDict
+
+    def fresh_copy(self):
+        """Return a fresh copy graph with the same data structure.
+
+        A fresh copy has no nodes, edges or graph attributes. It is
+        the same data structure as the current graph. This method is
+        typically used to create an empty version of the graph.
+        """
+        return OrderedGraph()
+
 
 def merge_graphs(graph, *graphs, **kwargs):
     """Merges a bunch of graphs into a new graph.
@@ -178,7 +255,7 @@ def merge_graphs(graph, *graphs, **kwargs):
         raise ValueError("Overlap detection callback expected to be callable")
     elif overlap_detector is None:
         overlap_detector = (lambda to_graph, from_graph:
-                            len(to_graph.subgraph(from_graph.nodes_iter())))
+                            len(to_graph.subgraph(from_graph.nodes)))
     for g in graphs:
         # This should ensure that the nodes to be merged do not already exist
         # in the graph that is to be merged into. This could be problematic if
