@@ -21,6 +21,10 @@ import six
 from six.moves import zip as compat_zip
 
 from taskflow import exceptions as exc
+from taskflow import logging
+
+
+LOG = logging.getLogger(__name__)
 
 
 def _parse_hosts(hosts):
@@ -171,23 +175,37 @@ def make_client(conf):
     - ``handler``: a kazoo handler object that can be used to provide the
       client with alternate async strategies (the default is `thread`_
       based, but `gevent`_, or `eventlet`_ ones can be provided as needed)
+    - ``keyfile`` : SSL keyfile to use for authentication
+    - ``keyfile_password``: SSL keyfile password
+    -  ``certfile``: SSL certfile to use for authentication
+    - ``ca``: SSL CA file to use for authentication
+    - ``use_ssl``: argument to control whether SSL is used or not
+    - ``verify_certs``: when using SSL, argument to bypass
+        certs verification
 
-    .. _client: http://kazoo.readthedocs.org/en/latest/api/client.html
-    .. _kazoo: kazoo.readthedocs.org/
-    .. _retry: http://kazoo.readthedocs.org/en/latest/api/retry.html
-    .. _gevent: http://kazoo.readthedocs.org/en/latest/api/\
+    .. _client: https://kazoo.readthedocs.io/en/latest/api/client.html
+    .. _kazoo: https://kazoo.readthedocs.io/
+    .. _retry: https://kazoo.readthedocs.io/en/latest/api/retry.html
+    .. _gevent: https://kazoo.readthedocs.io/en/latest/api/\
                 handlers/gevent.html
-    .. _eventlet: http://kazoo.readthedocs.org/en/latest/api/\
+    .. _eventlet: https://kazoo.readthedocs.io/en/latest/api/\
                   handlers/eventlet.html
-    .. _thread: http://kazoo.readthedocs.org/en/latest/api/\
+    .. _thread: https://kazoo.readthedocs.io/en/latest/api/\
                 handlers/threading.html
     """
-    # See: http://kazoo.readthedocs.org/en/latest/api/client.html
+    # See: https://kazoo.readthedocs.io/en/latest/api/client.html
     client_kwargs = {
         'read_only': bool(conf.get('read_only')),
         'randomize_hosts': bool(conf.get('randomize_hosts')),
+        'logger': LOG,
+        'keyfile': conf.get('keyfile', None),
+        'keyfile_password': conf.get('keyfile_password', None),
+        'certfile': conf.get('certfile', None),
+        'use_ssl': conf.get('use_ssl', False),
+        'verify_certs': conf.get('verify_certs', True),
+
     }
-    # See: http://kazoo.readthedocs.org/en/latest/api/retry.html
+    # See: https://kazoo.readthedocs.io/en/latest/api/retry.html
     if 'command_retry' in conf:
         client_kwargs['command_retry'] = conf['command_retry']
     if 'connection_retry' in conf:
