@@ -78,7 +78,7 @@ def create_flow_detail(flow, book=None, backend=None, meta=None):
     flow_id = uuidutils.generate_uuid()
     flow_name = getattr(flow, 'name', None)
     if flow_name is None:
-        LOG.warn("No name provided for flow %s (id %s)", flow, flow_id)
+        LOG.warning("No name provided for flow %s (id %s)", flow, flow_id)
         flow_name = flow_id
 
     flow_detail = models.FlowDetail(name=flow_name, uuid=flow_id)
@@ -88,7 +88,7 @@ def create_flow_detail(flow, book=None, backend=None, meta=None):
         flow_detail.meta.update(meta)
 
     if backend is not None and book is None:
-        LOG.warn("No logbook provided for flow %s, creating one.", flow)
+        LOG.warning("No logbook provided for flow %s, creating one.", flow)
         book = temporary_log_book(backend)
 
     if book is not None:
